==> geoportal-data-common-2.0.1-20230117.155940-3-servicearchive.tar.gz: CHANGELOG.md <==

# Changelog

All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v2.0.1-SNAPSHOT] - 2022-01-12

#### Bug fixes

- [#24263] Fixing JSON library v20090211
- [#24432] Fixing serialization issue using LinkedHashMap<String, String> instead of LinkedHashMap<String, Object>

## [v2.0.0] - 2022-11-17

#### Enhancements
 
- [#22883] Integrated the configurations exposed by (the new) geoportal-client (>= 1.1.0-SNAPSHOT)
- Passed to UCD/Projects geoportal client/service
- [#23835] Integrated with WORKFLOW_ACTION_LIST_GUI configuration
- [#23909] Declared lombok required for JDK_11
- [#23913] Integrated with GUI presentation configurations read from IS
- [#23927] Integrated with Relationship definition in UCD
- [#23834] Integrated with the create/view/delete Relationship facility
- [#24136] Integrated the temporal dimension on the front-end side

## [v1.4.0] - 2022-06-08

#### Enhancements

- [#23392] Implemented the "Clone Project" facility
- [#23457] Implemented the "Publish/UnPublish Project" facility

## [v1.3.0] - 2021-12-03

#### Enhancements

- [#22506] Added classes to read configurations and common classes from the GNA components: DataEntry and DataViewer

## [v1.2.0] - 2021-09-29

#### Enhancements

- [#20595] Porting common model
- [#21890] Passed to mongoID
- [#22002] Integrated with ValidationReport bean
- [#22040] Revisited the "Abstract Relazione di Scavo"
- Passed to gcube-bom 2.0.1


## [v1.0.0] - 2020-12-01

- First release

==> geoportal-data-common-2.0.1-20230119.134927-4-servicearchive.tar.gz: CHANGELOG.md <==

# Changelog

All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v2.0.1-SNAPSHOT] - 2022-01-19

#### Bug fixes

- [#24263] Fixing JSON library v20090211
- [#24432] Fixing serialization issue using LinkedHashMap<String, String> instead of LinkedHashMap<String, Object>.
- [#24432] Added a trim for returning value to solve a space as suffix into returned date (fixing the data displayed in the Timeline Widget)

## [v2.0.0] - 2022-11-17

#### Enhancements
 
- [#22883] Integrated the configurations exposed by (the new) geoportal-client (>= 1.1.0-SNAPSHOT)
- Passed to UCD/Projects geoportal client/service
- [#23835] Integrated with WORKFLOW_ACTION_LIST_GUI configuration
- [#23909] Declared lombok required for JDK_11
- [#23913] Integrated with GUI presentation configurations read from IS
- [#23927] Integrated with Relationship definition in UCD
- [#23834] Integrated with the create/view/delete Relationship facility
- [#24136] Integrated the temporal dimension on the front-end side
- [#24458] Published projects cannot be edited/updated

## [v1.4.0] - 2022-06-08

#### Enhancements

- [#23392] Implemented the "Clone Project" facility
- [#23457] Implemented the "Publish/UnPublish Project" facility

## [v1.3.0] - 2021-12-03

#### Enhancements

- [#22506] Added classes to read configurations and common classes from the GNA components: DataEntry and DataViewer

## [v1.2.0] - 2021-09-29

#### Enhancements

- [#20595] Porting common model
- [#21890] Passed to mongoID
- [#22002] Integrated with ValidationReport bean
- [#22040] Revisited the "Abstract Relazione di Scavo"
- Passed to gcube-bom 2.0.1


## [v1.0.0] - 2020-12-01

- First release
